@@ -19,8 +19,6 @@ def ebt_listmaker(
         CreateEventTask(
             allet, nameet, policy_dict, computer_group_dict, NEW_HOST, NEW_API_KEY
         )
-    else:
-        pass
 
 
 def st_listmaker(
@@ -85,16 +83,28 @@ def CreateEventTask(
         modet = []
         for task in allet:
             task_json = rename_json(json.loads(task))
+            oldname = task_json.get("name")
             actions_list = task_json.get("actions")
             if actions_list is not None:
                 for action in actions_list:
                     oldid = action.get("parameterValue")
                     if oldid is not None:
-                        if action["type"] == "assign-policy":
-                            action["parameterValue"] = policy_dict[oldid]
-                        elif action["type"] == "assign-group":
+                        if (computer_group_dict.get(oldid) is not None) and (action["type"] == "assign-group"):
                             action["parameterValue"] = computer_group_dict[oldid]
-            modet.append(json.dumps(task_json))
+                        elif computer_group_dict.get(oldid) is None:
+                            print(
+                                f"WARNING: THE COMPUTER GROUP ASSIGNED IN {oldname} DOES NOT EXIST. TASK WILL NOT BE MIGRATED"
+                            )
+                            task_json = {}
+                        if (policy_dict.get(oldid) is not None) and (action["type"] == "assign-policy"):
+                            action["parameterValue"] = policy_dict[oldid]
+                        elif policy_dict.get(oldid) is None:
+                            print(
+                                f"WARNING: THE POLICY ASSIGNED IN {oldname} DOES NOT EXIST. TASK WILL NOT BE MIGRATED"
+                            )
+                            task_json = {}
+            if task_json:
+                modet.append(json.dumps(task_json))
 
         validate_create(modet, EventBasedTasksApiInstance(tenant2key), "Event Based")
 
@@ -149,19 +159,36 @@ def CreateScheduledTask(
         modst = []
         for task in allst:
             task_json = rename_json(json.loads(task))
+            oldname = task_json.get("name")
             oldcomputergroup = nested_lookup("computerGroupID", task_json)
             oldpolicy = nested_lookup("policyID", task_json)
+            has_smartfolder = bool(nested_lookup("smartFolderID", task_json))
             if oldcomputergroup:
                 oldid = oldcomputergroup[0]
-                task_json = nested_update(
-                    task_json,
-                    "computerGroupID",
-                    computer_group_dict[oldid],
-                )
-            oldpolicy = nested_lookup("policyID", task_json)
+                if computer_group_dict.get(oldid) is not None:
+                    task_json = nested_update(
+                        task_json,
+                        "computerGroupID",
+                        computer_group_dict[oldid],
+                    )
+                else:
+                    print(
+                        f"WARNING: THE COMPUTER GROUP ASSIGNED IN {oldname} DOES NOT EXIST. TASK WILL NOT BE MIGRATED"
+                    )
+                    task_json = {}
             if oldpolicy:
                 oldid = oldpolicy[0]
-                task_json = nested_update(task_json, "policyID", policy_dict[oldid])
-            modst.append(json.dumps(task_json))
+                if computer_group_dict.get(oldid) is not None:
+                    task_json = nested_update(task_json, "policyID", policy_dict[oldid])
+                else:
+                    print(
+                        f"WARNING: THE POLICY ASSIGNED IN {oldname} DOES NOT EXIST. TASK WILL NOT BE MIGRATED"
+                    )
+                    task_json = {}
+            if has_smartfolder:
+                print(f"WARNING: THE SMART FOLDER ASSIGNED IN {oldname} CANNOT BE MIGRATED.")
+                task_json = {}
+            if task_json:
+                modst.append(json.dumps(task_json))
 
         validate_create(modst, ScheduledTasksApiInstance(tenant2key), "Scheduled")
